# pylint: disable=unused-import
from .generated.wallet_pb2 import (
  BCY_BLOCKCYPHER,
  BTC_BLOCKCYPHER,
  BTC_BLOCKSTREAM,
  BTC_MEMPOOLSPACE,
  BTC_BTCDOTCOM,
  BTC_BLOCKCHAIN_INFO,
  BTC_ESPLORA,
  BTC_FULLNODE,
  BTCTEST_BLOCKCYPHER,
  BTCTEST_BLOCKSTREAM,
  BTCTEST_MEMPOOLSPACE,
  BTCTEST_ESPLORA,
  BTCTEST_FULLNODE,
  DASH_BLOCKCYPHER,
  DASH_FULLNODE,
  DOGE_BLOCKCYPHER,
  ETH_QUICKNODE,
  ETH_ALCHEMY,
  ETH_GETBLOCK,
  ETH_INFURA,
  ETH_FULLNODE,
  LTC_BLOCKCYPHER,
  LTC_FULLNODE
)



import requests

from ...errors import NetworkException

async def broadcast_transaction_btctest_blockcypher(raw_transaction_hex):
    api_url = "https://api.blockcypher.com/v1/btc/test3/txs/push"
    payload = {"tx": raw_transaction_hex}

    try:
        response = requests.post(api_url, json=payload, timeout=30)
    except Exception as e:
        raise NetworkException("Connection error while broadcasting transaction: {}".format(str(e)))

    if response.status_code >= 300:
        raise NetworkException("Failed to broadcast testnet transaction using Blockcypher API: {}".format(response.text))



import asyncio
import binascii
import hashlib
from .fullnode import *


def tx_hash_dogetest(raw_transaction_hex):
    return binascii.hexlify(hashlib.sha256(hashlib.sha256(raw_transaction_hex.decode()).digest()).digest())

async def broadcast_transaction_dogetest(raw_transaction_hex, **kwargs):
    rpc_nodes = kwargs.get('rpc_nodes') or []

    tasks = []

    for node in rpc_nodes:
        tasks.append(asyncio.create_task(broadcast_transaction_dogetest_full_node(raw_transaction_hex, **node)))
    
    try:
        await asyncio.gather(*tasks, return_exceptions=True)
    except Exception as e:
        pass